/*
 * Test program to use game controller buttons as Bluetooth keyboard input
 */

#define USE_NIMBLE
#include <BleKeyboard.h>

BleKeyboard bleKeyboard;

#define GP_UP 16
#define GP_DOWN 17
#define GP_LEFT 18
#define GP_RIGHT 19
#define GP_A 21
#define GP_B 22

bool keyStates[6] = {false, false, false, false, false, false};
int keyPins[6] = {GP_UP, GP_DOWN, GP_LEFT, GP_RIGHT, GP_A, GP_B};
uint8_t keyCodes[6] = {'\'', '/', 'z', 'x', 'd', 'f'};


void setup() {
  Serial.begin(115200);
  Serial.println("Code running...");
  setInputs();
  bleKeyboard.begin();
}

bool connectNotificationSent = false;

void loop() {
  int counter;
  if(bleKeyboard.isConnected()) {
    if (!connectNotificationSent) {
      Serial.println("Code connected...");
      connectNotificationSent = true;
    }
    for(counter = 0; counter < 6; counter ++){
      handleButton(counter);
    }
  }
}

void setInputs() {
  pinMode(GP_UP, INPUT_PULLUP);
  pinMode(GP_DOWN, INPUT_PULLUP);
  pinMode(GP_LEFT, INPUT_PULLUP);
  pinMode(GP_RIGHT, INPUT_PULLUP);
  pinMode(GP_A, INPUT_PULLUP);
  pinMode(GP_B, INPUT_PULLUP);
}

void handleButton(int keyIndex){
  // handle the button press
  if (!digitalRead(keyPins[keyIndex])){
    // button pressed
    if (!keyStates[keyIndex]){
      // key not currently pressed
      keyStates[keyIndex] = true;
      bleKeyboard.press(keyCodes[keyIndex]);
    }
  }
  else {
    // button not pressed
    if (keyStates[keyIndex]){
      // key currently pressed
      keyStates[keyIndex] = false;
      bleKeyboard.release(keyCodes[keyIndex]);
    }
  }
}
